//
//  BSAAdContainerView.h
//  BSAAdFramework
//
//  Created by Rick Fillion on 6/28/10.
//  Copyright 2010 BuySellAds. All rights reserved.
//

#import <Cocoa/Cocoa.h>
#import "BSAAdView.h"
#import "BSAAdViewDelegate.h"

@class BSAAd;
@class BSAAdContainerView;

/**
 @brief The BSAAdContainerViewDelegate protocol defines the optional methods implemented by delegates of BSAAdContainerView objects.

 */
@protocol BSAAdContainerViewDelegate

/** Sent to the delegate before the container handles the click of an ad.  
 Return NO if the container should not handle it, if for example the 
 delegate will handle it itself.
 */
- (BOOL)adContainerView:(BSAAdContainerView*)adContainerView shouldHandleClickOfAd:(BSAAd *)ad;

@end


/**
 @brief Main view class that will displays ads loaded by BSAAdController.
 
 There is one required property to set in order to use BSAAdContainerView, which
 is the zoneIdentifier property.  
 
 BSAAdContainerView does only basic drawing itself (a background color, and a
 border).  You may find it suitable to subclass it to do custom drawing in 
 -drawRect:.  
 
 */
@interface BSAAdContainerView : NSView <BSAAdViewDelegate> {
    NSNumber *zoneIdentifier;
    NSColor *backgroundColor;
    NSArray *ads;
    id<BSAAdContainerViewDelegate> delegate;
    BOOL bordered;
}

/// The unique zone identifier
@property (nonatomic, retain) NSNumber *zoneIdentifier;
/// The background color used to draw behind ads
@property (nonatomic, retain) NSColor *backgroundColor;
/// Controls whether the container view draws its border or not
@property (nonatomic, assign, getter=isBordered) BOOL bordered;
/// Ads currently being displayed in this container view
@property (nonatomic, readonly) NSArray *ads;
/// delegate
@property (nonatomic, assign) id<BSAAdContainerViewDelegate> delegate;


/**
 @brief Randomly chooses ads to display in the view. 
 
 Randomly chooses ads to display in the view based on what was loaded in the 
 BSAAdController.  You may choose to periodically call this method using
 a timer to display different ads (or different orders of ads) in your 
 application.
 
 */
- (void)refresh;

/**
 @brief Returns the BSAAdView subclass that will be used for ads.
 
 The default implementation of this method looks up the zone format for
 the zone associated with this BSAAdContainerView, and will return 
 either BSAAdImageView for image-only ads or BSAAdImageAndTextView
 for Image and Text ads.
 
 */
- (Class)adViewClass;

@end
